Index: Source/WebKit/chromium/src/WebViewImpl.cpp |
=================================================================== |
--- Source/WebKit/chromium/src/WebViewImpl.cpp (revision 90510) |
+++ Source/WebKit/chromium/src/WebViewImpl.cpp (working copy) |
@@ -1144,15 +1144,19 @@ |
m_recreatingGraphicsContext = false; |
return; |
} |
- doComposite(); |
- // Finish if requested. |
- if (finish) |
- m_layerRenderer->finish(); |
+ // Do not composite if the compositor context is already lost. |
+ if (!m_layerRenderer->isCompositorContextLost()) { |
+ doComposite(); |
- // Put result onscreen. |
- m_layerRenderer->present(); |
+ // Finish if requested. |
+ if (finish) |
+ m_layerRenderer->finish(); |
+ // Put result onscreen. |
+ m_layerRenderer->present(); |
+ } |
+ |
if (m_layerRenderer->isCompositorContextLost()) { |
// Trying to recover the context right here will not work if GPU process |
// died. This is because GpuChannelHost::OnErrorMessage will only be |